VersionStatus class

Information about the app's current version, and the most recent version available in the Apple App Store or Google Play Store.

Constructors

VersionStatus({required String localVersion, required String storeVersion, required String appStoreLink, bool forceUpdate = false, String? releaseNotes, String? originalStoreVersion})

Properties

A link to the app store page where the app can be updated.
final
canUpdate → bool
Returns true if the store version of the application is greater than the local version.
no setter
forceUpdate → bool
final
hashCode → int
The hash code for this object.
no setterinherited
localVersion → String
The current version of the app.
final
originalStoreVersion → String?
The most recent version of the app in the store.
final
releaseNotes → String?
The release notes for the store version of the app.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storeVersion → String
The most recent version of the app in the store.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited