UiConfigParser class

Utility class to parse UI configuration from the API response

Constructors

UiConfigParser()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getBool(Map<String, dynamic>? uiConfig, String key, bool defaultValue) → bool
Get a boolean value from uiConfig with a default
getDouble(Map<String, dynamic>? uiConfig, String key, double defaultValue) → double
Get a double value from uiConfig with a default
getInt(Map<String, dynamic>? uiConfig, String key, int defaultValue) → int
Get an integer value from uiConfig with a default
getString(Map<String, dynamic>? uiConfig, String key, String defaultValue) → String
Get a string value from uiConfig with a default
parseColor(String? colorString, String defaultColor) → Color
Parse a color from a hex string (e.g., "#FF5733" or "FF5733") Returns a default color if parsing fails